@@ -1,10 +1,9 @@
-/* 
+/*
  *
- * $Id: k3baudioclient.cpp 369057 2004-12-07 14:05:11Z trueg $
  * Copyright (C) 2004 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,30 +16,30 @@
 #include "k3baudioserver.h"
 
 
-K3bAudioClient::K3bAudioClient()
-  : m_attached(false)
+K3b::AudioClient::AudioClient()
+    : m_attached(false)
 {
 }
 
 
-K3bAudioClient::~K3bAudioClient()
+K3b::AudioClient::~AudioClient()
 {
 }
 
 
-void K3bAudioClient::startStreaming()
+void K3b::AudioClient::startStreaming()
 {
-  if( !m_attached ) {
-    K3bAudioServer::instance()->attachClient( this );
-    m_attached = true;
-  }
+    if( !m_attached ) {
+        K3b::AudioServer::instance()->attachClient( this );
+        m_attached = true;
+    }
 }
 
 
-void K3bAudioClient::stopStreaming()
+void K3b::AudioClient::stopStreaming()
 {
-  if( m_attached ) {
-    K3bAudioServer::instance()->detachClient( this );
-    m_attached = false;
-  }
+    if( m_attached ) {
+        K3b::AudioServer::instance()->detachClient( this );
+        m_attached = false;
+    }
 }
