@@ -1,17 +1,16 @@
 /*
-*
-* $Id: k3bvcdtrack.h 619556 2007-01-03 17:38:12Z trueg $
-* Copyright (C) 2003-2004 Christian Kvasny <chris@k3b.org>
-*
-* This file is part of the K3b project.
-* Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
-*
-* This program is free software; you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
-* (at your option) any later version.
-* See the file "COPYING" for the exact licensing terms.
-*/
+ *
+ * Copyright (C) 2003-2004 Christian Kvasny <chris@k3b.org>
+ *
+ * This file is part of the K3b project.
+ * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ * See the file "COPYING" for the exact licensing terms.
+ */
 
 #ifndef K3BVCDTRACK_H
 #define K3BVCDTRACK_H
@@ -20,7 +19,6 @@
 #include <qstring.h>
 #include <qfileinfo.h>
 #include <qfile.h>
-#include <qptrlist.h>
 
 // Kde Includes
 #include <kio/global.h>
@@ -28,19 +26,21 @@
 // K3b Includes
 #include "mpeginfo/k3bmpeginfo.h"
 #include "k3b_export.h"
-class LIBK3B_EXPORT K3bVcdTrack
-{
+
+namespace K3b {
+    class LIBK3B_EXPORT VcdTrack
+    {
     public:
-        K3bVcdTrack( QPtrList<K3bVcdTrack>* parent, const QString& filename );
-        ~K3bVcdTrack();
+        VcdTrack( QList<VcdTrack*>* parent, const QString& filename );
+        ~VcdTrack();
 
         QString fileName() const
         {
             return QFileInfo( m_file ).fileName();
         }
-        QString absPath() const
+        QString absolutePath() const
         {
-            return QFileInfo( m_file ).absFilePath();
+            return QFileInfo( m_file ).absoluteFilePath();
         }
         KIO::filesize_t size() const;
         int index() const;
@@ -64,13 +64,13 @@ class LIBK3B_EXPORT K3bVcdTrack
         enum PbcTracks { PREVIOUS, NEXT, RETURN, DEFAULT, AFTERTIMEOUT, _maxPbcTracks };
         enum PbcTypes { DISABLED, VIDEOEND };
 
-        void addToRevRefList( K3bVcdTrack* revreftrack );
-        void delFromRevRefList( K3bVcdTrack* revreftrack );
+        void addToRevRefList( VcdTrack* revreftrack );
+        void delFromRevRefList( VcdTrack* revreftrack );
         bool hasRevRef();
         void delRefToUs();
         void delRefFromUs();
 
-        void setPbcTrack( int, K3bVcdTrack* pbctrack = 0L );
+        void setPbcTrack( int, VcdTrack* pbctrack = 0L );
         void setPbcNonTrack( int, int );
         void setUserDefined( int, bool );
         void setPlayTime( int t )
@@ -102,7 +102,7 @@ class LIBK3B_EXPORT K3bVcdTrack
             return m_pbcnumkeysuserdefined;
         };
 
-        K3bVcdTrack* getPbcTrack( const int& );
+        VcdTrack* getPbcTrack( const int& );
         int getNonPbcTrack( const int& );
         bool isPbcUserDefined( int );
         int getPlayTime()
@@ -119,7 +119,7 @@ class LIBK3B_EXPORT K3bVcdTrack
         }
 
         // Numeric keys
-        void setDefinedNumKey( int key, K3bVcdTrack* track )
+        void setDefinedNumKey( int key, VcdTrack* track )
         {
             m_definedkeysmap.insert( key, track );
         }
@@ -131,38 +131,38 @@ class LIBK3B_EXPORT K3bVcdTrack
         {
             m_definedkeysmap.clear();
         }
-        QMap<int, K3bVcdTrack*> DefinedNumKey()
+        QMap<int, VcdTrack*> DefinedNumKey()
         {
             return m_definedkeysmap;
         }
 
         // Mpeg Infos
-        const QString resolution();
-        const QString highresolution();
-        const QString video_frate();
-        const QString video_bitrate();
-        const QString audio_layer();
-        const QString audio_bitrate();
-        const QString audio_sampfreq();
+        QString resolution();
+        QString highresolution();
+        QString video_frate();
+        QString video_bitrate();
+        QString audio_layer();
+        QString audio_bitrate();
+        QString audio_sampfreq();
 
-        const QString duration()
+        QString duration()
         {
             return SecsToHMS( mpeg_info->playing_time );
         };
-        const int version()
+        int version()
         {
             return mpeg_info->version;
         };
-        const unsigned long muxrate()
+        unsigned long muxrate()
         {
             return mpeg_info->muxrate;
         };
-        const QString video_format( );
-        const QString video_chroma( );
-        const QString audio_mode( );
-        const QString audio_copyright( );
-        const QString mpegTypeS( bool audio = false );
-        const int mpegType();
+        QString video_format( );
+        QString video_chroma( );
+        QString audio_mode( );
+        QString audio_copyright( );
+        QString mpegTypeS( bool audio = false );
+        int mpegType();
 
         void PrintInfo();
 
@@ -170,17 +170,17 @@ class LIBK3B_EXPORT K3bVcdTrack
 
     protected:
 
-        const QString audio_type2str( unsigned int , unsigned int, unsigned int );
+        QString audio_type2str( unsigned int , unsigned int, unsigned int );
         QString SecsToHMS( double );
 
-        QPtrList<K3bVcdTrack>* m_parent;
+        QList<VcdTrack*>* m_parent;
 
         // PBC
-        QPtrList<K3bVcdTrack>* m_revreflist;          // List of Tracks which points to us
-        QMap<int, K3bVcdTrack*> m_pbctrackmap;        // Pbc Tracks (Previous, Next, ...)
+        QList<VcdTrack*> m_revreflist;          // List of Tracks which points to us
+        QMap<int, VcdTrack*> m_pbctrackmap;        // Pbc Tracks (Previous, Next, ...)
         QMap<int, int> m_pbcnontrackmap;              // Pbc NON Track types (Previous, Next, ...)
         QMap<int, bool> m_pbcusrdefmap;               // Pbc is userdefined or defaults (Previous, Next, ...)
-        QMap<int, K3bVcdTrack*> m_definedkeysmap;
+        QMap<int, VcdTrack*> m_definedkeysmap;
 
         bool m_pbcnumkeys;
         bool m_pbcnumkeysuserdefined;
@@ -193,6 +193,7 @@ class LIBK3B_EXPORT K3bVcdTrack
         int m_filetype;
         QFile m_file;
         QString m_title;
-};
+    };
+}
 
 #endif
