@@ -1,6 +1,5 @@
-/* 
+/*
  *
- * $Id: sourceheader 380067 2005-01-19 13:03:46Z trueg $
  * Copyright (C) 2005 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -19,44 +18,50 @@
 #include <qeventloop.h>
 #include <qapplication.h>
 
+class K3b::SignalWaiter::Private
+{
+public:
+    QEventLoop loop;
+};
 
-K3bSignalWaiter::K3bSignalWaiter()
-  : QObject(),
-    m_inLoop(true)
+
+K3b::SignalWaiter::SignalWaiter()
+    : QObject(),
+      d( new Private() )
 {
 }
 
 
-K3bSignalWaiter::~K3bSignalWaiter()
+K3b::SignalWaiter::~SignalWaiter()
 {
+    delete d;
 }
 
 
-void K3bSignalWaiter::waitForSignal( QObject* o, const char* signal )
+void K3b::SignalWaiter::waitForSignal( QObject* o, const char* signal )
 {
-  K3bSignalWaiter w;
-  connect( o, signal,
-	   &w, SLOT(slotSignal()) );
+    K3b::SignalWaiter w;
+    connect( o, signal,
+             &w, SLOT(slotSignal()) );
 
-  QApplication::eventLoop()->enterLoop();
+    w.d->loop.exec();
 }
 
 
-void K3bSignalWaiter::waitForJob( K3bJob* job )
+void K3b::SignalWaiter::waitForJob( K3b::Job* job )
 {
-  if( !job->active() )
-    return;
+    if( !job->active() )
+        return;
 
-  waitForSignal( job, SIGNAL(finished(bool)) );
+    waitForSignal( job, SIGNAL(finished(bool)) );
 }
 
 
-void K3bSignalWaiter::slotSignal()
+void K3b::SignalWaiter::slotSignal()
 {
-  if( m_inLoop ) {
-    m_inLoop = false;
-    QApplication::eventLoop()->exitLoop();
-  }
+    if( d->loop.isRunning() ) {
+        d->loop.exit();
+    }
 }
 
 #include "k3bsignalwaiter.moc"
