@@ -1,6 +1,5 @@
 /* 
  *
- * $Id: k3bdataprojectinterface.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -21,16 +20,19 @@
 
 #include <qstringlist.h>
 
-class K3bDataDoc;
+namespace K3b {
+    class DataDoc;
+}
 
 
-class K3bDataProjectInterface : public K3bProjectInterface
+namespace K3b {
+class DataProjectInterface : public ProjectInterface
 {
   K_DCOP
 
  public:
-  K3bDataProjectInterface( K3bDataDoc*, const char* name = 0 );
-  ~K3bDataProjectInterface();
+  DataProjectInterface( DataDoc* );
+  ~DataProjectInterface();
 
  k_dcop:
   /**
@@ -99,7 +101,8 @@ class K3bDataProjectInterface : public K3bProjectInterface
   bool setSortWeight( const QString& path, long weight ) const;
 
  private:
-  K3bDataDoc* m_dataDoc;
+  DataDoc* m_dataDoc;
 };
+}
 
 #endif
