@@ -1,6 +1,5 @@
 /* 
  *
- * $Id: k3bmixedprojectinterface.cpp 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -20,27 +19,27 @@
 #include <kapplication.h>
 #include <dcopclient.h>
 
-#include <k3bmixeddoc.h>
-#include <k3bdatadoc.h>
-#include <k3baudiodoc.h>
+#include "k3bmixeddoc.h"
+#include "k3bdatadoc.h"
+#include "k3baudiodoc.h"
 
 
-K3bMixedProjectInterface::K3bMixedProjectInterface( K3bMixedDoc* doc, const char* name )
-  : K3bProjectInterface( doc, name ),
+K3b::MixedProjectInterface::MixedProjectInterface( K3b::MixedDoc* doc )
+  : K3b::ProjectInterface( doc ),
     m_mixedDoc( doc )
 {
-  m_dataInterface = new K3bDataProjectInterface( doc->dataDoc(), objId() + "-datapart" );
-  m_audioInterface = new K3bAudioProjectInterface( doc->audioDoc(), objId() + "-audiopart" );
+  m_dataInterface = new K3b::DataProjectInterface( doc->dataDoc(), objId() + "-datapart" );
+  m_audioInterface = new K3b::AudioProjectInterface( doc->audioDoc(), objId() + "-audiopart" );
 }
 
 
-DCOPRef K3bMixedProjectInterface::dataPart() const
+DCOPRef K3b::MixedProjectInterface::dataPart() const
 {
   return DCOPRef( kapp->dcopClient()->appId(), m_dataInterface->objId() );
 }
 
 
-DCOPRef K3bMixedProjectInterface::audioPart() const
+DCOPRef K3b::MixedProjectInterface::audioPart() const
 {
   return DCOPRef( kapp->dcopClient()->appId(), m_audioInterface->objId() );
 }
