@@ -1,10 +1,9 @@
 /* 
  *
- * $Id: k3bsplash.h 619556 2007-01-03 17:38:12Z trueg $
- * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 2003-2008 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
- * Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
+ * Copyright (C) 1998-2008 Sebastian Trueg <trueg@k3b.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -17,7 +16,7 @@
 #ifndef K3BSPLASH_H
 #define K3BSPLASH_H
 
-#include <qvbox.h>
+#include <KVBox>
 
 class QLabel;
 class QMouseEvent;
@@ -25,24 +24,26 @@ class QPaintEvent;
 class QString;
 
 
-class K3bSplash : public QVBox
+namespace K3b {
+class Splash : public KVBox
 {
-Q_OBJECT
+    Q_OBJECT
 
- public:
-  K3bSplash( QWidget* parent = 0, const char* name = 0 );
-  ~K3bSplash();
+public:
+    Splash( QWidget* parent = 0 );
+    ~Splash();
 
- public slots:
-  void show();
-  void addInfo( const QString& );
+public Q_SLOTS:
+    void show();
+    void addInfo( const QString& );
 
- protected:
-  void mousePressEvent( QMouseEvent* );
-  //  void paintEvent( QPaintEvent* );
+protected:
+    void mousePressEvent( QMouseEvent* );
+    //  void paintEvent( QPaintEvent* );
 
- private:
-  QLabel* m_infoBox;
+private:
+    QLabel* m_infoBox;
 };
+}
 
 #endif
