@@ -1,6 +1,5 @@
 /* 
  *
- * $Id: k3bexternalbinoptiontab.h 619556 2007-01-03 17:38:12Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -21,29 +20,32 @@
 
 
 
-class QPushButton;
-class QListViewItem;
-class KListView;
-class K3bExternalBinManager;
-class K3bExternalBinWidget;
+namespace K3b {
+    class ExternalBinManager;
+}
+namespace K3b {
+    class ExternalBinWidget;
+}
 
 
-class K3bExternalBinOptionTab : public QWidget
+namespace K3b {
+class ExternalBinOptionTab : public QWidget
 {
 Q_OBJECT
 
  public:
-  K3bExternalBinOptionTab( K3bExternalBinManager*, QWidget*, const char* name = 0 );
-  ~K3bExternalBinOptionTab();
+  ExternalBinOptionTab( ExternalBinManager*, QWidget* = 0 );
+  ~ExternalBinOptionTab();
 
   void readSettings();
   void saveSettings();
 
  private:
-  K3bExternalBinManager* m_manager;
+  ExternalBinManager* m_manager;
 
-  K3bExternalBinWidget* m_externalBinWidget;
+  ExternalBinWidget* m_externalBinWidget;
 };
+}
 
 
 
