@@ -1,52 +1,58 @@
 /*
-*
-* $Id: k3bvcdtrackdialog.h 619556 2007-01-03 17:38:12Z trueg $
-* Copyright (C) 2003-2004 Christian Kvasny <chris@k3b.org>
-*
-* This file is part of the K3b project.
-* Copyright (C) 1998-2007 Sebastian Trueg <trueg@k3b.org>
-*
-* This program is free software; you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by
-* the Free Software Foundation; either version 2 of the License, or
-* (at your option) any later version.
-* See the file "COPYING" for the exact licensing terms.
-*/
+ *
+ * Copyright (C) 2003-2004 Christian Kvasny <chris@k3b.org>
+ * Copyright (C) 2008 Sebastian Trueg <trueg@k3b.org>
+ *
+ * This file is part of the K3b project.
+ * Copyright (C) 1998-2008 Sebastian Trueg <trueg@k3b.org>
+ *
+ * This program is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ * See the file "COPYING" for the exact licensing terms.
+ */
 
 #ifndef K3BVCDTRACKDIALOG_H
 #define K3BVCDTRACKDIALOG_H
 
-#include <kdialogbase.h>
-#include <qptrlist.h>
+#include <kdialog.h>
+#include <qlist.h>
 #include <qtabwidget.h>
+#include <QLabel>
 
-#include <k3bvcddoc.h>
-#include <k3blistview.h>
+#include "k3bvcddoc.h"
+
+#include <KComboBox>
 
-class K3bVcdTrack;
 class QLabel;
 class QCheckBox;
-class QComboBox;
 class QGroupBox;
-class QRadioButton;
-class QButtonGroup;
-class KCutLabel;
-class K3bCutComboBox;
+class QSpinBox;
+class KSqueezedTextLabel;
 
+namespace K3b {
+    class ListView;
+    class VcdTrack;
 
-class K3bVcdTrackDialog : public KDialogBase
-{
+#ifdef __GNUC__
+#warning We need a simple replacement for CutComboBox
+#endif
+    typedef KComboBox CutComboBox;
+
+    class VcdTrackDialog : public KDialog
+    {
         Q_OBJECT
 
     public:
-        K3bVcdTrackDialog( K3bVcdDoc*, QPtrList<K3bVcdTrack>& tracks, QPtrList<K3bVcdTrack>& selectedTracks, QWidget* parent = 0, const char* name = 0 );
-        ~K3bVcdTrackDialog();
+        VcdTrackDialog( VcdDoc*, QList<VcdTrack*>& tracks, QList<VcdTrack*>& selectedTracks, QWidget* parent = 0 );
+        ~VcdTrackDialog();
 
-    protected slots:
+    protected Q_SLOTS:
         void slotOk();
         void slotApply();
 
-    private slots:
+    private Q_SLOTS:
         void slotPlayTimeChanged( int );
         void slotWaitTimeChanged( int );
         void slotPbcToggled( bool );
@@ -55,13 +61,13 @@ class K3bVcdTrackDialog : public KDialogBase
 
 
     private:
-        K3bVcdDoc* m_vcdDoc;
-        QPtrList<K3bVcdTrack> m_tracks;
-        QPtrList<K3bVcdTrack> m_selectedTracks;
-        QMap<QString, K3bVcdTrack*> m_numkeysmap;
+        VcdDoc* m_vcdDoc;
+        QList<VcdTrack*> m_tracks;
+        QList<VcdTrack*> m_selectedTracks;
+        QMap<QString, VcdTrack*> m_numkeysmap;
         QTabWidget* m_mainTabbed;
 
-        KCutLabel* m_displayFileName;
+        KSqueezedTextLabel* m_displayFileName;
         QLabel* m_labelMimeType;
         QLabel* m_displaySize;
         QLabel* m_displayLength;
@@ -88,17 +94,17 @@ class K3bVcdTrackDialog : public KDialogBase
         QGroupBox* m_groupKey;
         QWidget* m_widgetnumkeys;
 
-        K3bCutComboBox* m_pbc_previous;
-        K3bCutComboBox* m_pbc_next;
-        K3bCutComboBox* m_pbc_return;
-        K3bCutComboBox* m_pbc_default;
-        K3bCutComboBox* m_comboAfterTimeout;
+        CutComboBox* m_pbc_previous;
+        CutComboBox* m_pbc_next;
+        CutComboBox* m_pbc_return;
+        CutComboBox* m_pbc_default;
+        CutComboBox* m_comboAfterTimeout;
 
         QCheckBox* m_check_reactivity;
         QCheckBox* m_check_pbc;
         QCheckBox* m_check_usekeys;
         QCheckBox* m_check_overwritekeys;
-        K3bListView* m_list_keys;
+        ListView* m_list_keys;
 
         QSpinBox* m_spin_times;
         QSpinBox* m_spin_waittime;
@@ -111,13 +117,15 @@ class K3bVcdTrackDialog : public KDialogBase
         void fillGui();
         void fillPbcGui();
 
-        void setPbcTrack( K3bVcdTrack*, K3bCutComboBox*, int );
+        void setPbcTrack( VcdTrack*, CutComboBox*, int );
         void setDefinedNumKeys( );
-        QString displayName( K3bVcdTrack* );
-        K3bVcdOptions* VcdOptions()
+        QString displayName( VcdTrack* );
+
+        K3b::VcdOptions* VcdOptions()
         {
             return m_vcdDoc->vcdOptions();
         }
-};
+    };
+}
 
 #endif
